@@ -5,6 +5,7 @@
 # pylint: disable-msg=no-member
 import time
 import pulseio
+import pwmio
 import board
 import digitalio
 import adafruit_irremote
@@ -14,8 +15,8 @@ button = digitalio.DigitalInOut(board.D4)
 button.direction = digitalio.Direction.INPUT
 button.pull = digitalio.Pull.DOWN
 
-# Create a 'pulseio' output, to send infrared signals on the IR transmitter @ 38KHz
-pwm = pulseio.PWMOut(board.IR_TX, frequency=38000, duty_cycle=2 ** 15)
+# Create a 'pwmio' output, to send infrared signals on the IR transmitter @ 38KHz
+pwm = pwmio.PWMOut(board.IR_TX, frequency=38000, duty_cycle=2 ** 15)
 pulseout = pulseio.PulseOut(pwm)
 # Create an encoder that will take numbers and turn them into NEC IR pulses
 encoder = adafruit_irremote.GenericTransmit(
